@@ -3,6 +3,9 @@ import logging
 import schedule
 import datetime
 import time
+import threading
+import datetime
+from zoneinfo import ZoneInfo
 
 from pexpect import TIMEOUT
 from telegram import Update
@@ -50,7 +53,7 @@ def get_ruuvi_data():
     for ruuvi_data_point in ruuvi_data:
         logging.info("Apending name for " + ruuvi_data_point)
         ruuvi_data[ruuvi_data_point]["name"] = ruuvi_tags[ruuvi_data_point]["name"]
-        ruuvi_data[ruuvi_data_point]["temperature_calibrated"] = (
+        ruuvi_data[ruuvi_data_point]["temperature_calibrated"] = "{:.2f}".format(
             ruuvi_data[ruuvi_data_point]["temperature"]
             + ruuvi_tags[ruuvi_data_point]["temperatureOffset"]
         )
@@ -65,8 +68,9 @@ def get_ruuvi_data():
     )
     for ruuvi_data_point in ruuvi_data.values():
         c.execute(
-            "INSERT INTO ruuvi VALUES (datetime('now'), ?, ?, ?, ?, ?)",
+            "INSERT INTO ruuvi VALUES (?, ?, ?, ?, ?, ?)",
             (
+                datetime.datetime.now(ZoneInfo("Europe/Helsinki")).strftime("%Y-%m-%dT%H:%M:%S %Z"),
                 ruuvi_data_point["name"],
                 ruuvi_data_point["temperature"],
                 ruuvi_data_point["temperature_calibrated"],
@@ -139,9 +143,15 @@ async def temperature(update: Update, context: ContextTypes.DEFAULT_TYPE):
         )
         data = c.fetchone()
         # Calculate the time since the last update
-        time_since_update = datetime.datetime.now() - datetime.datetime.strptime(data[0], '%Y-%m-%d %H:%M:%S')
-        text += f"{data[1]}: {data[3]} °C  ({ time_since_update / datetime.timedelta(minutes=1) } minuuttia sitten) \n" 
-    
+        time_since_update = datetime.datetime.now() - datetime.datetime.strptime(
+            data[0], "%Y-%m-%dT%H:%M:%S %Z"
+        )
+
+        if time_since_update > datetime.timedelta(minutes=15):
+            text += f"{data[1]}: {data[3]} °C  ({int(time_since_update / datetime.timedelta(minutes=1)) } minuuttia sitten) \n"
+        else:
+            text += f"{data[1]}: {data[3]} °C \n"
+
     await context.bot.send_message(chat_id=update.effective_chat.id, text=text)
 
 
@@ -277,13 +287,15 @@ def main():
     # Update ruuvi data every 5 minutes
     schedule.every(5).minutes.do(get_ruuvi_data)
 
-    application.updater.start_polling()
-
-    while True:
-        schedule.run_pending()
-        time.sleep(1)
-
+    def run_schedule():
+            schedule.run_pending()
+            time.sleep(1)
     
+    thread = threading.Thread(target=run_schedule, daemon=True, name="schedule_thread")
+    thread.start()
+
+    application.run_polling()
+
 
 if __name__ == "__main__":
     main()
